---
title: '[릴리즈노트] 2024-05-08 업데이트'
category: 업데이트
tags:
  - 관리자콘솔
  - 업데이트
searchTags:
  - 빌링결제 내역조회
  - 빌링결제 캘린더
  - 빌링결제
  - 릴리즈노트
datetime: 2024-05-08T15:00:00.000Z
---

<Callout title="2024년 05월 08일 관리자콘솔 업데이트 소식을 안내드립니다." />



### **주요 업데이트 사항**

✔️ 빌링결제 내역조회 페이지가 새롭게 오픈했습니다.

새로운 빌링결제 내역 조회 페이지에서는 빌링키 결제 및 결제 예약건에 대해 한 번에 조회 및 관리할 수 있습니다.

**\[상세 내역 조회]**

- 빌링키 결제 내역을 상태별로 조회할 수 있습니다.
- 콘솔 화면에서 결제 예약일 변경, 예약 해지, 결제 즉시 재시도, 결제 재예약을 할 수 있습니다.
- 리커버리 기능을 설정하여 결제 실패 건에 대한 일괄 재시도를 자동화할 수 있습니다.
  - 포트원 V1 결제 서비스의 경우 결제예약 API(Schedule API)를 이용한 결제 예약 건 중 결제 실패 상태인 거래 건에 한하여 리커버리 기능을 사용할 수 있습니다. 비 인증 결제(빌링키) API(Again API) 건에 대한 리커버리 기능은 상반기 내로 업데이트될 예정입니다.
  - 포트원 V2 결제 서비스의 경우 빌링키 결제 API 및 결제 예약 API를 이용한 결제 건 중 결제 실패 상태인 거래 건에 한하여 리커버리 기능을 사용할 수 있습니다.

\[빌링결제 캘린더]

- 빌링결제 건에 대한 월간/일간 데이터를 확인할 수 있습니다.
- [포트원 빌링결제 내역 가이드 보러가기↗](https://developers.portone.io/opi/ko/console/guide/billing-payments?v=v2)

[\[관리자콘솔 릴리즈노트\] 2024-05-08 업데이트 보러가기↗](https://developers.portone.io/release-notes/console/2024-05-08)
